@@ -248,13 +248,29 @@ class VisGUIFrame(AUIFrame, visCore.VisGUICore):
 
 
     def OnAbout(self, event):
-        msg = "PYME Visualise\n\n Visualisation of localisation microscopy data\nDavid Baddeley 2009"
+        from PYME.version import version
+        from PYME.resources import getIconPath
+        import wx.adv
+        # msg = "PYME Visualise\n\n Visualisation of localisation microscopy data\nDavid Baddeley 2009"
               
-        dlg = wx.MessageDialog(self, msg, "About PYME Visualise",
-                               wx.OK | wx.ICON_INFORMATION)
-        dlg.SetFont(wx.Font(8, wx.NORMAL, wx.NORMAL, wx.NORMAL, False, "Verdana"))
-        dlg.ShowModal()
-        dlg.Destroy()
+        # dlg = wx.MessageDialog(self, msg, "About PYME Visualise",
+        #                        wx.OK | wx.ICON_INFORMATION)
+        # dlg.SetFont(wx.Font(8, wx.NORMAL, wx.NORMAL, wx.NORMAL, False, "Verdana"))
+        # dlg.ShowModal()
+        # dlg.Destroy()
+
+        dlg = wx.adv.AboutDialogInfo()
+        dlg.SetName("PYME Visualise")
+        dlg.SetVersion(version)
+        dlg.SetDescription("Visualisation of localisation microscopy data.")
+        dlg.SetCopyright("(C)2009-2020")
+        dlg.SetIcon(wx.Icon(getIconPath('pymeLogo.png')))
+        #dlg.SetLicense("GPLv3") # I think we need to either expand or omit
+        # TODO: should this be the issues page or the website
+        dlg.SetWebSite("https://github.com/python-microscopy/python-microscopy/issues", desc="Report an issue")        
+        #dlg.AddDeveloper("David Baddeley") #should probably be all or none here, punting full list for now
+
+        wx.adv.AboutBox(dlg)
 
 #    def OnToggleWindow(self, event):
 #        self._mgr.ShowPane(self._leftWindow1,not self._leftWindow1.IsShown())
