@@ -330,27 +330,24 @@ class RecipePusher(object):
     @property
     def _taskTemplate(self):
         task = '''{"id": "{{ruleID}}~{{taskID}}",
-              "type": "recipe",
-              "inputs" : {{taskInputs}},
-              %s,
-              %s
-              }'''
-
+                            "type": "recipe",
+                            "inputs" : {{taskInputs}},
+                            %s
+                        }'''
+    
         if self.output_dir is None:
             output_dir_n = ''
         else:
-            output_dir_n = '"output_dir": "%s",' % self.output_dir
-        
+            output_dir_n = '"output_dir": "%s",\n    ' % self.output_dir
+    
         if self.recipeURI:
-            task = task % ('"taskdefRef" : "%s"' % self.recipeURI, output_dir_n)
+            task = task % (output_dir_n + '"taskdefRef" : "%s"' % self.recipeURI)
         else:
-            task = task % ('"taskdef" : {"recipe": "%s"}' % self.recipe_text, output_dir_n)
+            task = task % (output_dir_n + '"taskdef" : {"recipe": "%s"}' % self.recipe_text)
             
-
         return task
 
 
-
     def fileTasksForInputs(self, **kwargs):
         from PYME.IO import clusterIO
         input_names = kwargs.keys()
@@ -365,7 +362,7 @@ class RecipePusher(object):
         inputs_by_task = {frameNum: {k : inputs[k][frameNum] for k in inputs.keys()} for frameNum in range(numTotalFrames)}
 
         rule = {'template': self._taskTemplate, 'inputsByTask' : inputs_by_task}
-
+        
         s = clusterIO._getSession(self.taskQueueURI)
         r = s.post('%s/add_integer_id_rule?max_tasks=%d&release_start=%d&release_end=%d' % (self.taskQueueURI,numTotalFrames, 0, numTotalFrames), data=json.dumps(rule),
                         headers = {'Content-Type': 'application/json'})
@@ -380,4 +377,3 @@ class RecipePusher(object):
         
 
 
-
